#ifndef MODAPI_DEF_H
#define MODAPI_DEF_H

#define DIALOG				M_DIALOG
#define DIALOG_RECORDS		M_DIALOG_RECORDS
#define DIALOG_LISTE		M_DIALOG_LISTE
#define DIALOG_MENU			M_DIALOG_MENU
#define DIALOG_MENUPOPUP	M_DIALOG_MENUPOPUP
#define DIALOG_TEXTBOX		M_DIALOG_TEXTBOX
#define FIELD_COMBO			M_FIELD_COMBO
#define FIELD_COMBO_MANY	M_FIELD_COMBO_MANY
#define FIELD_LIST			M_FIELD_LIST
#define FIELD_CLIST			M_FIELD_CLIST
#define FIELD_ENUM			M_FIELD_ENUM
#define FIELD_BUTTON_TEXT	M_FIELD_BUTTON_TEXT
#define FIELD_BUTTON_ICON	M_FIELD_BUTTON_ICON

#endif

